ROMPAK         EQU     $C000                                      

BS             EQU     8                           * BACKSPACE                  
CR             EQU     $D                          * ENTER KEY                   
ESC            EQU     $1B                         * ESCAPE CODE                       
LF             EQU     $A                          * LINE FEED                   
FORMF          EQU     $C                          * FORM FEED                      
SPACE          EQU     $20                         * SPACE (BLANK)                           

STKBUF         EQU     58                          * STACK BUFFER ROOM                               
DEBDEL         EQU     $45E                        * DEBOUNCE DELAY                              
LBUFMX         EQU     250                         * MAX NUMBER OF CHARS IN A BASIC LINE                                                  
MAXLIN         EQU     $FA                         * MAXIMUM MS BYTE OF LINE NUMBER                                             

DOSBUF         EQU     $2600                       * RAM LOAD LOCATION FOR THE DOS COMMAND                                                      
FATCON         EQU     6                           * NUMBER OF CONTROL BYTES BEFORE FAT                                               
FCBCON         EQU     25                          * NUMBER OF CONTROL BYTES BEFORE FCB                                                
DIRLEN         EQU     32                          * NUMBER OF BYTES IN DIRECTORY ENTRY                                                
SECLEN         EQU     256                         * LENGTH OF SECTOR IN BYTES                                        
SECMAX         EQU     18                          * MAXIMUM NUMBER OF SECTORS PER TRACK                                                 
TRKLEN         EQU     SECMAX*SECLEN    	   * LENGTH OF TRACK IN BYTES                                                   
TRKMAX         EQU     35                          * MAX NUMBER OF TRACKS                                  
FATLEN         EQU     ((TRKMAX-1)*2)+6		   * FILE ALLOCATION TABLE LENGTH                                                     
GRANMX         EQU     (TRKMAX-1)*2     	   * MAXIMUM NUMBER OF GRANULES                                                     
FCBLEN         EQU     SECLEN+25                   * FILE CONTROL BLOCK LENGTH                                              
INPFIL         EQU     $10                         * INPUT FILE TYPE                              
OUTFIL         EQU     $20                         * OUTPUT FILE TYPE                               
RANFIL         EQU     $40                         * RANDOM/DIRECT FILE TYPE                                      

* SUPER EXTENDED BASIC EQUATES
ROWMAX         EQU     24                          * MAXIMUM NUMBER OF ROWS IN HI-RES PRINT MODE                                                         
RAMLINK        EQU     0                           * DUMMY RAM LINK VECTOR                                   
HRESSCRN       EQU     $2000                       * ADDRESS OF THE HI-RES SCREEN IN THE CPU'S MEMORY SPACE                                                                         
HRESBUFF       EQU     $C000                       * ADDRESS OF THE GET/PUT BUFFERS IN THE CPU'S MEMORY SPACE                                                                           
TMPSTACK       EQU     $DFFF                       * ADDRESS OF THE HI-RES GRAPHICS STACK IN THE CPU'S MEMORY SPACE                                                                                 
EBHITOK        EQU     $62                         * FIRST ENHANCED BASIC TOKEN NUMBER                                                 
EBHISTOK       EQU     $29                         * FIRST ENHANCED BASIC FUNCTION TOKEN NUMBER BUG - SHOULD BE $28                                                                               
CURCHAR        EQU     SPACE                       * HI-RES CURSOR CHARACTER                                         

* HBUFF HGET/HPUT BUFFER HEADER EQUATES
HB.ADDR        EQU     0                           * ADDRESS OF THE NEXT BUFFER - 2 BYTES                                                  
HB.NUM         EQU     2                           * NUMBER OF THIS BUFFER - 1 BYTES                                            
HB.SIZE        EQU     3                           * NUMBER OF BYTES IN THE BUFFER - 2 BYTES                                                     
HB.LEN         EQU     5                           * NUMBER OF BYTES IN THIS HEADER                                           

* VIDEO REGISTER EQUATES
* INIT0 BIT EQUATES
COCO           EQU     $80                         * 1 = Color Computer compatible                                          
MMUEN          EQU     $40                         * 1 = MMU enabled                             
IEN            EQU     $20                         * 1 = GIME chip IRQ output enabled                                            
FEN            EQU     $10                         * 1 = GIME chip FIRQ output enabled                                             
MC3            EQU     8                           * 1 = RAM at XFEXX is constant                                      
MC2            EQU     4                           * 1 = standard SCS                          
MC1            EQU     2                           * ROM map control                         
MC0            EQU     1                           * ROM map control                         

* INTERRUPT REQUEST ENABLED
TMR            EQU     $20                         * TIMER                 
HBORD          EQU     $10                         * HORIZONTAL BORDER                               
VBORD          EQU     8                           * VERTICAL BORDER                           
EI2            EQU     4                           * SERIAL DATA                     
EI1            EQU     2                           * KEYBOARD                  
EI0            EQU     1                           * CARTRIDGE                   

* EXPANDED MEMORY DEFINITIONS
BLOCK6.0       EQU     $30                         * BLOCKS $30-$33 ARE THE HI-RES GRAPHICS SCREEN                                                              
BLOCK6.1       EQU     $31                         * HI-RES GRAPHICS SCREEN                                       
BLOCK6.2       EQU     $32                         * HI-RES GRAPHICS SCREEN                                       
BLOCK6.3       EQU     $33                         * HI-RES GRAPHICS SCREEN                                       
BLOCK6.4       EQU     $34                         * GET/PUT BUFFER                               
BLOCK6.5       EQU     $35                         * STACK AREA FOR HI-RES GRAPHICS COMMAND                                                       
BLOCK6.6       EQU     $36                         * CHARACTER POINTERS                                   
BLOCK6.7       EQU     $37                         * UNUSED BY BASIC                                

* BLOCKS $48-$4F ARE USED FOR THE BASIC OPERATING SYSTEM
BLOCK7.0       EQU     $38                                        
BLOCK7.1       EQU     $39                                        
BLOCK7.2       EQU     $3A                                        
BLOCK7.3       EQU     $3B                                        
BLOCK7.4       EQU     $3C                                        
BLOCK7.5       EQU     $3D                                        
BLOCK7.6       EQU     $3E                                        
BLOCK7.7       EQU     $3F                                        

* PSEUDO PSEUDO OPS
SKP1           EQU     $21                         * OP CODE OF BRN - SKIP ONE BYTE                                           
SKP2           EQU     $8C                         * OP CODE OF CMPX # - SKIP TWO BYTES                                               
SKP1LD         EQU     $86                         * OP CODE OF LDA # - SKIP THE NEXT BYTE                                                    
*                                   AND LOAD THE VALUE OF THAT BYTE INTO ACCA - THIS
*                                   IS USUALLY USED TO LOAD ACCA WITH A NON ZERO VALUE


               ORG     0                                
* SETDP 0

ENDFLG         RMB     1                           * STOP/END FLAG: POSITIVE=STOP, NEG=END                                                  
CHARAC         RMB     1                           * TERMINATOR FLAG 1                              
ENDCUR         RMB     1                           * TERMINATOR FLAG 2                              
TMPLOC         RMB     1                           * SCRATCH VARIABLE                             
IFCTR          RMB     1                           * IF COUNTER - HOW MANY IF STATEMENTS IN A LINE                                                         
DIMFLG         RMB     1                           *DV* ARRAY FLAG 0=EVALUATE, 1=DIMENSIONING                                                     
VALTYP         RMB     1                           *DV* *PV TYPE FLAG: 0=NUMERIC, $FF=STRING                                                    
GARBFL         RMB     1                           *TV STRING SPACE HOUSEKEEPING FLAG                                             
ARYDIS         RMB     1                           * DISABLE ARRAY SEARCH: 00=ALLOW SEARCH                                                  
INPFLG         RMB     1                           *TV INPUT FLAG: READ=0, INPUT<>0                                           
RELFLG         RMB     1                           *TV RELATIONAL OPERATOR FLAG                                       
TEMPPT         RMB     2                           *PV TEMPORARY STRING STACK POINTER                                             
LASTPT         RMB     2                           *PV ADDR OF LAST USED STRING STACK ADDRESS                                                     
TEMPTR         RMB     2                           * TEMPORARY POINTER                              
TMPTR1         RMB     2                           * TEMPORARY DESCRIPTOR STORAGE (STACK SEARCH)                                                        
** FLOATING POINT ACCUMULATOR #2 (MANTISSA ONLY)
FPA2           RMB     4                           * FLOATING POINT ACCUMULATOR #2 MANTISSA                                                 
BOTSTK         RMB     2                           * BOTTOM OF STACK AT LAST CHECK                                          
TXTTAB         RMB     2                           *PV BEGINNING OF BASIC PROGRAM                                         
VARTAB         RMB     2                           *PV START OF VARIABLES                                 
ARYTAB         RMB     2                           *PV START OF ARRAYS                              
ARYEND         RMB     2                           *PV END OF ARRAYS (+1)                                 
FRETOP         RMB     2                           *PV START OF STRING STORAGE (TOP OF FREE RAM)                                                        
STRTAB         RMB     2                           *PV START OF STRING VARIABLES                                        
FRESPC         RMB     2                           * UTILITY STRING POINTER                                   
MEMSIZ         RMB     2                           *PV TOP OF STRING SPACE                                  
OLDTXT         RMB     2                           * SAVED LINE NUMBER DURING A "STOP"                                              
BINVAL         RMB     2                           * BINARY VALUE OF A CONVERTED LINE NUMBER                                                    
OLDPTR         RMB     2                           * SAVED INPUT PTR DURING A "STOP"                                            
TINPTR         RMB     2                           * TEMPORARY INPUT POINTER STORAGE                                            
DATTXT         RMB     2                           *PV 'DATA' STATEMENT LINE NUMBER POINTER                                                   
DATPTR         RMB     2                           *PV 'DATA' STATEMENT ADDRESS POINTER                                               
DATTMP         RMB     2                           * DATA POINTER FOR 'INPUT' & 'READ'                                              
VARNAM         RMB     2                           *TV TEMP STORAGE FOR A VARIABLE NAME                                               
VARPTR         RMB     2                           *TV POINTER TO A VARIABLE DESCRIPTOR                                               
VARDES         RMB     2                           * TEMP POINTER TO A VARIABLE DESCRIPTOR                                                  
RELPTR         RMB     2                           * POINTER TO RELATIONAL OPERATOR PROCESSING ROUTINE                                                              
TRELFL         RMB     1                           * TEMPORARY RELATIONAL OPERATOR FLAG BYTE                                                    

* FLOATING POINT ACCUMULATORS #3,4 & 5 ARE MOSTLY
* USED AS SCRATCH PAD VARIABLES.
** FLOATING POINT ACCUMULATOR #3 :PACKED: ($40-$44)
V40            RMB     1                                   
V41            RMB     1                                   
V42            RMB     1                                   
V43            RMB     1                                   
V44            RMB     1                                   
** FLOATING POINT ACCUMULATOR #4 :PACKED: ($45-$49)
V45            RMB     1                                   
V46            RMB     1                                   
V47            RMB     1                                   
V48            RMB     2                                   
** FLOATING POINT ACCUMULATOR #5 :PACKED: ($4A-$4E)
V4A            RMB     1                                   
V4B            RMB     2                                   
V4D            RMB     2                                   
** FLOATING POINT ACCUMULATOR #0
FP0EXP         RMB     1                           *PV FLOATING POINT ACCUMULATOR #0 EXPONENT                                                     
FPA0           RMB     4                           *PV FLOATING POINT ACCUMULATOR #0 MANTISSA                                                   
FP0SGN         RMB     1                           *PV FLOATING POINT ACCUMULATOR #0 SIGN                                                 
COEFCT         RMB     1                           * POLYNOMIAL COEFFICIENT COUNTER                                           
STRDES         RMB     5                           * TEMPORARY STRING DESCRIPTOR                                        
FPCARY         RMB     1                           * FLOATING POINT CARRY BYTE                                      
** FLOATING POINT ACCUMULATOR #1
FP1EXP         RMB     1                           *PV FLOATING POINT ACCUMULATOR #1 EXPONENT                                                     
FPA1           RMB     4                           *PV FLOATING POINT ACCUMULATOR #1 MANTISSA                                                   
FP1SGN         RMB     1                           *PV FLOATING POINT ACCUMULATOR #1 SIGN                                                 

RESSGN         RMB     1                           * SIGN OF RESULT OF FLOATING POINT OPERATION                                                       
FPSBYT         RMB     1                           * FLOATING POINT SUB BYTE (FIFTH BYTE)                                                 
COEFPT         RMB     2                           * POLYNOMIAL COEFFICIENT POINTER                                           
LSTTXT         RMB     2                           * CURRENT LINE POINTER DURING LIST                                             
CURLIN         RMB     2                           *PV CURRENT LINE # OF BASIC PROGRAM, $FFFF = DIRECT                                                              
DEVCFW         RMB     1                           *TV TAB FIELD WIDTH                              
DEVLCF         RMB     1                           *TV TAB ZONE                       
DEVPOS         RMB     1                           *TV PRINT POSITION                             
DEVWID         RMB     1                           *TV PRINT WIDTH                          
PRTDEV         RMB     1                           *TV PRINT DEVICE: 0=NOT CASSETTE, -1=CASSETTE                                                        
DEVNUM         RMB     1                           *PV DEVICE NUMBER: -3=DLOAD, -2=PRINTER,                                                   
*                                                      -1=CASSETTE, 0=SCREEN, 1-15=DISK
CINBFL         RMB     1                           *PV CONSOLE IN BUFFER FLAG: 00=NOT EMPTY, $FF=EMPTY                                                              
RSTFLG         RMB     1                           *PV WARM START FLAG: $55=WARM, OTHER=COLD                                                    
RSTVEC         RMB     2                           *PV WARM START VECTOR - JUMP ADDRESS FOR WARM START                                                              
TOPRAM         RMB     2                           *PV TOP OF RAM                         
               RMB     2                           * SPARE: UNUSED VARIABLES                              
FILSTA         RMB     1                           *PV FILE STATUS FLAG: 0=CLOSED, 1=INPUT, 2=OUTPUT                                                            
CINCTR         RMB     1                           *PV CONSOLE IN BUFFER CHAR COUNTER                                             
CINPTR         RMB     2                           *PV CONSOLE IN BUFFER POINTER                                        
BLKTYP         RMB     1                           *TV CASS BLOCK TYPE: 0=HEADER, 1=DATA, $FF=EOF                                                         
BLKLEN         RMB     1                           *TV CASSETTE BYTE COUNT                                  
CBUFAD         RMB     2                           *TV CASSETTE LOAD BUFFER POINTER                                           
CCKSUM         RMB     1                           *TV CASSETTE CHECKSUM BYTE                                     
CSRERR         RMB     1                           *TV ERROR FLAG/CHARACTER COUNT                                         
CPULWD         RMB     1                           *TV PULSE WIDTH COUNT                                
CPERTM         RMB     1                           *TV BIT COUNTER                          
CBTPHA         RMB     1                           *TV BIT PHASE FLAG                             
CLSTSN         RMB     1                           *TV LAST SINE TABLE ENTRY                                    
GRBLOK         RMB     1                           *TV GRAPHIC BLOCK VALUE FOR SET, RESET AND POINT                                                           
IKEYIM         RMB     1                           *TV INKEY$ RAM IMAGE                               
CURPOS         RMB     2                           *PV CURSOR LOCATION                              
ZERO           RMB     2                           *PV DUMMY - THESE TWO BYTES ARE ALWAYS ZERO                                                    
SNDTON         RMB     1                           *TV TONE VALUE FOR SOUND COMMAND                                           
SNDDUR         RMB     2                           *TV DURATION VALUE FOR SOUND COMMAND                                               

** THESE BYTES ARE MOVED DOWN FROM ROM
***                                 INIT         DESCRIPTION
*                                   VALUE
CMPMID         RMB     1                           * 18  *PV 1200/2400 HERTZ PARTITION                                              
CMP0           RMB     1                           * 24  *PV UPPER LIMIT OF 1200 HERTZ PERIOD                                                   
CMP1           RMB     1                           * 10  *PV UPPER LIMIT OF 2400 HERTZ PERIOD                                                   
SYNCLN         RMB     2                           * 128  *PV NUMBER OF $55'S TO CASSETTE LEADER                                                        
BLKCNT         RMB     1                           * 11  *PV CURSOR BLINK DELAY                                       
LPTBTD         RMB     2                           * 88  *PV BAUD RATE CONSTANT (600)                                             
LPTLND         RMB     2                           * 1  *PV PRINTER CARRIAGE RETURN DELAY                                                 
LPTCFW         RMB     1                           * 16  *PV TAB FIELD WIDTH                                    
LPTLCF         RMB     1                           * 112  *PV LAST TAB ZONE                                   
LPTWID         RMB     1                           * 132  *PV PRINTER WIDTH                                   
LPTPOS         RMB     1                           * 0  *PV LINE PRINTER POSITION                                         
EXECJP         RMB     2                           * LB4AA  *PV JUMP ADDRESS FOR EXEC COMMAND                                                     

** THIS ROUTINE PICKS UP THE NEXT INPUT CHARACTER FROM
** BASIC. THE ADDRESS OF THE NEXT BASIC BYTE TO BE
** INTERPRETED IS STORED AT CHARAD.

GETNCH         RMB     12
GETCCH	       EQU	$A5
CHARAD	       EQU	$A6
*               INC     <CHARAD+1                   *PV INCREMENT LS BYTE OF INPUT POINTER                                                         
*               BNE     GETCCH                      *PV BRANCH IF NOT ZERO (NO CARRY)                                           
*               INC     <CHARAD                     *PV INCREMENT MS BYTE OF INPUT POINTER                                                 
*GETCCH         FCB     $B6                         *PV OP CODE OF LDA EXTENDED                                        
* CHARAD 2  *PV THESE 2 BYTES CONTAIN ADDRESS OF THE CURRENT
*                                   CHARACTER WHICH THE BASIC INTERPRETER IS
*                                   PROCESSING
*               JMP     BROMHK                      * JUMP BACK INTO THE BASIC RUM                                        

VAB            RMB     1                           * = LOW ORDER FOUR BYTES OF THE PRODUCT                                               
VAC            RMB     1                           * = OF A FLOATING POINT MULTIPLICATION                                              
VAD            RMB     1                           * = THESE BYTES ARE USE AS RANDOM DATA                                              
VAE            RMB     1                           * = BY THE RND STATEMENT                                

* EXTENDED BASIC VARIABLES
TRCFLG         RMB     1                           *PV TRACE FLAG 0=OFF ELSE=ON                                       
USRADR         RMB     2                           *PV ADDRESS OF THE START OF USR VECTORS                                                  
FORCOL         RMB     1                           *PV FOREGROUND COLOR                               
BAKCOL         RMB     1                           *PV BACKGROUND COLOR                               
WCOLOR         RMB     1                           *TV WORKING COLOR BEING USED BY EX BASIC                                                   
ALLCOL         RMB     1                           *TV ALL PIXELS IN THIS BYTE SET TO COLOR OF VB3                                                          
PMODE          RMB     1                           *PV PMODE'S MODE ARGUMENT                                   
ENDGRP         RMB     2                           *PV END OF CURRENT GRAPHIC PAGE                                          
HORBYT         RMB     1                           *PV NUMBER OF BYTES/HORIZONTAL GRAPHIC LINE                                                      
BEGGRP         RMB     2                           *PV START OF CURRENT GRAPHIC PAGE                                            
GRPRAM         RMB     1                           *PV START OF GRAPHIC RAM (MS BYTE)                                             
HORBEG         RMB     2                           *DV* *PV HORIZ COORD - START POINT                                             
VERBEG         RMB     2                           *DV* *PV VERT COORD - START POINT                                            
CSSYAL         RMB     1                           *PV SCREEN'S COLOR SET ARGUMENT                                          
SETFLG         RMB     1                           *PV PRESET/PSET FLAG: 0=PRESET, 1=PSET                                                 
HOREND         RMB     2                           *DV* *PV HORIZ COORD - ENDING POINT                                              
VEREND         RMB     2                           *DV* *PV VERT COORD - ENDING POINT                                             
HORDEF         RMB     2                           *PV HORIZ COORD - DEFAULT COORD                                          
VERDEF         RMB     2                           *PV VERT COORD - DEFAULT COORD                                         

* EXTENDED BASIC SCRATCH PAD VARIABLES
VCB            RMB     2                                   
VCD            RMB     2                                   
VCF            RMB     2                                   
VD1            RMB     2                                   
VD3            RMB     1                                   
VD4            RMB     1                                   
VD5            RMB     1                                   
VD6            RMB     1                                   
VD7            RMB     1                                   
VD8            RMB     1                                   
VD9            RMB     1                                   
VDA            RMB     1                                   

CHGFLG         RMB     1                           *TV FLAG TO INDICATE IF GRAPHIC DATA HAS BEEN CHANGED                                                                
TMPSTK         RMB     2                           *TV STACK POINTER STORAGE DURING PAINT                                                 
OCTAVE         RMB     1                           *PV OCTAVE VALUE (PLAY)                                  
VOLHI          RMB     1                           *DV* *PV VOLUME HIGH VALUE (PLAY)                                           
VOLLOW         RMB     1                           *DV* *PV VOLUME LOW VALUE (PLAY)                                           
NOTELN         RMB     1                           *PV NOTE LENGTH (PLAY)                                 
TEMPO          RMB     1                           *PV TEMPO VALUE (PLAY)                                
PLYTMR         RMB     2                           *TV TIMER FOR THE PLAY COMMAND                                         
DOTYAL         RMB     1                           *TV DOTTED NOTE TIMER SCALE FACTOR                                             
HRMODE         EQU                                 *             SUPER EXTENDED BASIC HI-RES MODE                                                        
DLBAUD         RMB     1                           *DV* *PV DLOAD BAUD RATE CONSTANT $B0=300, $2C=1200                                                              
HRWIDTH        EQU                                 *             SUPER EXTENDED BASIC HI-RES TEXT MODE                                                              
TIMOUT         RMB     1                           *DV* *PV DLOAD TIMEOUT CONSTANT                                          
ANGLE          RMB     1                           *DV* *PV ANGLE VALUE (DRAW)                                     
SCALE          RMB     1                           *DV* *PV SCALE VALUE (DRAW)                                     

* DSKCON VARIABLES
DCOPC          RMB     1                           *PV DSKCON OPERATION CODE 0-3                                       
DCDRV          RMB     1                           *PV DSKCON DRIVE NUMBER 0-3                                     
DCTRK          RMB     1                           *PV DSKCON TRACK NUMBER 0-34                                      
DSEC           RMB     1                           *PV DSKCON SECTOR NUMBER 1-18                                      
DCBPT          RMB     2                           *PV DSKCON DATA POINTER                                 
DCSTA          RMB     1                           *PV DSKCON STATUS BYTE                                

FCBTMP         RMB     2                           * TEMPORARY FCB POINTER                                  

               RMB     13                          * SPARE: UNUSED VARIABLES                               


*                                  BASIC EXBASICDOSBASIC

SW3VEC         RMB     3                           * $XXXX $XXXX $3B3B SWI3 VECTOR                                          
SW2VEC         RMB     3                           * $XXXX $XXXX $3B3B SWI2 VECTOR                                          
SWIVEC         RMB     3                           * $XXXX $XXXX $XXXX SWI VECTOR                                         
NMIVEC         RMB     3                           * $XXXX $XXXX $D7AE NMI VECTOR                                         
IRQVEC         RMB     3                           * $A9B3 $894C $D7BC IRQ VECTOR                                         
FRQVEC         RMB     3                           * $A0F6 $A0F6 $A0F6 FIRQ VECTOR                                          

* TIMVAL
USRJMP         RMB     3                           * JUMP ADDRESS FOR BASIC'S USR FUNCTION                                                  
*         RMB    2                 TIMER VALUE FOR EXBAS
*         RMB    1                 UNUSED BY EXBAS OR DISK BASIC
RVSEED         RMB     1                           * FLOATING POINT RANDOM NUMBER SEED EXPONENT                                                       
               RMB     4                           * MANTISSA: INITIALLY SET TO $804FC75259                                             
CASFLG         RMB     1                           * UPPER CASE/LOWER CASE FLAG: $FF=UPPER, 0=LOWER                                                           
DEBVAL         RMB     2                           * KEYBOARD DEBOUNCE DELAY (SET TO $45E)                                                  
EXPJMP         RMB     3                           * JUMP ADDRESS FOR EXPONENTIATION                                            
**                                 INITIALLY SET TO ERROR FOR BASIC, $8489 FOR EX BASIC

***       COMMAND INTERPRETATION VECTOR TABLE

** FOUR SETS OF 10 BYTE TABLES:


** THE LAST USED TABLE MUST BE FOLLOWED BY A ZERO BYTE
* THE JUMP TABLE VECTORS (3,4 AND 8,9) POINT TO THE JUMP TABLE FOR
* THE FIRST TABLE. FOR ALL OTHER TABLES, THESE VECTORS POINT TO A
* ROUTINE WHICH WILL VECTOR YOU TO THE CORRECT JUMP TABLE.
* SUPER ENHANCED BASIC HAS MODIFIED THIS SCHEME SO THAT THE USER
* TABLE MAY NOT BE ACCESSED.  ANY ADDITIONAL TABLES WILL HAVE TO BE
* ACCESSED FROM A NEW COMMAND HANDLER.

*         BYTE DESCRIPTION
*         0      NUMBER OF RESERVED WORDS
*         1,2    LOOKUP TABLE OF RESERVED WORDS
*         3,4    JUMP TABLE FOR COMMANDS (FIRST TABLE)
*                VECTOR TO EXPANSION COMMAND HANDLERS (ALL BUT FIRST TABLE)
*         5      NUMBER OF SECONDARY FUNCTIONS
*         6,7    LOOKUP TABLE OF SECONDARY FUNCTIONS (FIRST TABLE)
*                VECTOR TO EXPANSION SECONDARY COMMAND HANDLERS (ALL BUT
*                FIRST TABLE)
*         8,9    JUMP TABLE FOR SECONDARY FUNCTIONS
*         10     0 BYTE - END OF TABLE FLAG (LAST TABLE ONLY)

COMVEC         RMB     10                          * BASIC'S TABLE                           
               RMB     10                          * EX BASIC'S TABLE                        
               RMB     10                          * DISC BASIC'S TABLE (UNUSED BY EX BASIC)                                               

**** USR FUNCTION VECTOR ADDRESSES (EX BASIC ONLY)
               RMB     2                           * USR 0 VECTOR                   
               RMB     2                           * USR 1            
               RMB     2                           * USR 2            
               RMB     2                           * USR 3            
               RMB     2                           * USR 4            
               RMB     2                           * USR 5            
               RMB     2                           * USR 6            
               RMB     2                           * USR 7            
               RMB     2                           * USR 8            
               RMB     2                           * USR 9            

*** THE ABOVE 20 BYTE USR ADDR VECTOR TABLE IS MOVED TO
*** $95F-$972 BY DISC BASIC. THE 20 BYTES FROM $13E-$151
*** ARE REDEFINED AS FOLLOWS:

*         RMB    10                USER (SPARE) COMMAND INTERPRETATION TABLE SPACE
*         FCB    0                 END OF COMM INTERP TABLE FLAG
*         RMB    9                 UNUSED BY DISK BASIC

*         COMMAND INTERPRETATION TABLE VALUES
*                BYTE              BASIC EX BASIC
* DISK BASIC
*                                           BASIC TABLE
* BASIC TABLE
*                1,2               $AA66
*                3,4            $AB67
*                5              20
*                6,7            $AB1A
*                8,9            $AA29

*                0                           25              EX BASIC TABLE
*                1,2                         $8183
*                3,4                         $813C $CE2E ($CF0A 2.1)
*                5                           14
*                6,7                         $821E
*                8,9                         $8168 $CE56 ($CF32 2.1)

*                0                           19 (20 2.1)     DISK BASIC TABLE
*                1,2                         $C17F
*                3,4                         $C2C0
*                5                           6
*                6,7                         $C201
*                8,9                         $C236


KEYBUF         RMB     8                           * KEYBOARD MEMORY BUFFER                                   
POTVAL         RMB     1                           * LEFT VERTICAL JOYSTICK DATA                                        
               RMB     1                           * LEFT HORIZONTAL JOYSTICK DATA                                    
               RMB     1                           * RIGHT VERTICAL JOYSTICK DATA                                   
               RMB     1                           * RIGHT HORIZONTAL JOYSTICK DATA                                     

* BASIC'S RAM VECTORS - INITIALIZED TO RTS BY COLOR BASIC
* 25 SETS OF 3 BYTE INSTRUCTIONS WHICH ARE CALLED BY COLOR BASIC
* EXTENDED AND DISK BASIC. THEIR PURPOSE IS TO ALLOW ENHANCEMENTS (SUCH
* AS EX BASIC AND DOS BASIC) AS MORE ROMS ARE ADDED TO THE
* SYSTEM BY EFFECTIVELY ALLOWING MORE CODE TO BE ADDED TO THE
* ROUTINES IN EARLIER ROMS. THIS NEW CODE IS LOCATED IN THE NEW ROMS
* AND THE ADDRESS TO GET TO THE NEW CODE IS IN BYTES 1 & 2 OF THE
* RAM VECTOR. BYTE 0 WILL CONTAIN A $7E WHICH IS THE FIRST BYTE OF
* THE JMP INSTRUCTION.
* THE FIRST ADDRESS IN THIS TABLE IS THE ADDRESS IN BASIC WHICH
* CALLS THE RAM VECTOR, THE SECOND ADDRESS IS THE VALUE WHICH
* EX BASIC PUTS IN THE RAM VECTOR (IF ANY) AND THE THIRD ADDRESS
* IS THE VALUE WHICH DISK BASIC PUTS THERE (IF ANY)


*                               2.0          2.1      1.0    1.1
RVEC0          RMB     3                           * $A5F6 $C426 $C44B OPEN COMMAND                                          
RVEC1          RMB     3                           * $A5B9 $C838 $C888 DEVICE NUMBER VALIDITY CHECK                                                          
RVEC2          RMB     3                           * $A35F $C843 $C893 SET PRINT PARAMETERS                                                  
RVEC3          RMB     3                           * $A282 $8273 $CB4A $CC1C CONSOLE OUT                                               
RVEC4          RMB     3                           * $A176 $8CF1 $C58F $C5BC CONSOLE IN                                              
RVEC5          RMB     3                           * $A3ED $C818 $C848 INPUT DEVICE NUMBER CHECK                                                       
RVEC6          RMB     3                           * $A406 $C81B $C84B PRINT DEVICE NUMBER CHECK                                                       
RVEC7          RMB     3                           * $A426 $CA3B $CAE9 CLOSE ALL FILES                                             
RVEC8          RMB     3                           * $A42D $8286 $CA4B $CAF9 CLOSE ONE FILE                                                  
RVEC9          RMB     3                           * $B918 $8E90 $8E90 $8E90 PRINT                                         
RVEC10         RMB     3                           * $B061 $CC5B $CD35 INPUT                                    
RVEC11         RMB     3                           * $A549 $C859 $C8A9 BREAK CHECK                                          
RVEC12         RMB     3                           * $A390 $C6B7 $C6E4 INPUTTING A BASIC LINE                                                     
RVEC13         RMB     3                           * $A4BF $CA36 $CAE4 TERMINATING BASIC LINE INPUT                                                           
RVEC14         RMB     3                           * $A5CE $CA60 $C90C EOF COMMAND                                          
RVEC15         RMB     3                           * $B223 $8846 $CDF6 $CED2 EVALUATE AN EXPRESSION                                                           
RVEC16         RMB     3                           * $AC46 $C6B7 $C6E4 RESERVED FOR ON ERROR GOTO COMMAND                                                                 
RVEC17         RMB     3                           * $AC49 $88F0 $C24D $C265 ERROR DRIVER                                                 
RVEC18         RMB     3                           * $AE75 $829C $C990 $CA3E RUN                                        
RVEC19         RMB     3                           * $BD22 $87EF ASCII TO FLOATING POINT CONVERSION                                                           
RVEC20         RMB     3                           * $AD9E $82B9 $C8B0 BASIC'S COMMAND INTERPRETATION LOOP                                                                  
RVEC21         RMB     3                           * $A8C4 RESET/SET/POINT COMMANDS                                           
RVEC22         RMB     3                           * $A910 CLS                      
*                               $8162                               EXBAS' SECONDARY TOKEN HANDLER
*                               $8AFA                               EXBAS' RENUM TOKEN CHECK
*                               $975C                 $C29A $C2B2 EXBAS' GET/PUT
RVEC23         RMB     3                           * $B821 $8304 CRUNCH BASIC LINE                                          
RVEC24         RMB     3                           * $B7C2 UNCRUNCH BASIC LINE                                      

STRSTK         RMB     8*5            		   * STRING DESCRIPTOR STACK                                                
CFNBUF         RMB     9                           * CASSETTE FILE NAME BUFFER                                      
CASBUF         RMB     256                         * CASSETTE FILE DATA BUFFER                                        
LINHDR         RMB     2                           * LINE INPUT BUFFER HEADER                                     
LINBUF         RMB     LBUFMX+1                    * BASIC LINE INPUT BUFFER                                           
STRBUF         RMB     41                          * STRING BUFFER                           

VIDRAM         RMB     $200                         * VIDEO DISPLAY AREA                                 
	
*START OF ADDITIONAL RAM VARIABLE STORAGE (DISK BASIC ONLY)
DBUF0          RMB     SECLEN                      * I/O BUFFER #0                              
DBUF1          RMB     SECLEN                      * I/O BUFFER #1                              
FATBL0         RMB     FATLEN                      * FILE ALLOCATION TABLE - DRIVE 0                                                 
FATBL1         RMB     FATLEN                      * FILE ALLOCATION TABLE - DRIVE 1                                                 
FATBL2         RMB     FATLEN                      * FILE ALLOCATION TABLE - DRIVE 2                                                 
FATBL3         RMB     FATLEN                      * FILE ALLOCATION TABLE - DRIVE 3                                                 
FCBV1          RMB     16*2             	   * FILE BUFFER VECTORS (15 USER, 1 SYSTEM)                                                                 
RNBFAD         RMB     2                           * START OF FREE RANDOM FILE BUFFER AREA                                                  
FCBADR         RMB     2                           * START OF FILE CONTROL BLOCKS                                         
DNAMBF         RMB     8                           * DISK FILE NAME BUFFER                                  
DEXTBF         RMB     3                           * DISK FILE EXTENSION NAME BUFFER                                            
DFLTYP         RMB     1                           *DV* DISK FILE TYPE: 0=BASIC, 1=DATA, 2=MACHINE                                                          
*                                        LANGUAGE, 3=TEXT EDITOR SOURCE FILE
DASCFL         RMB     1                           *DV* ASCII FLAG: 0=CRUNCHED OR BINARY, $FF=ASCII                                                           
DRUNFL         RMB     1                           * RUN FLAG: (IF BIT 1=1 THEN RUN, IF BIT 0=1, THEN CLOSE                                                                   
*                                   ALL FILES BEFORE RUNNING)
DEFDRV         RMB     1                           * DEFAULT DRIVE NUMBER                                 
FCBACT         RMB     1                           * NUMBER OF FCBS ACTIVE                                  
DRESFL         RMB     1                           * RESET FLAG: <>0 WILL CAUSE A 'NEW' & SHUT DOWN ALL FCBS                                                                    
DLOADFL        RMB     1                           * LOAD FLAG: CAUSE A 'NEW' FOLLOWING A LOAD ERROR                                                             
DMRGFL         RMB     1                           * MERGE FLAG: 0=N0 MERGE, $FF=MERGE                                              
DUSRVC         RMB     20                          * DISK BASIC USR COMMAND VECTORS                                            
*** DISK FILE WORK AREA FOR DIRECTORY SEARCH
*   EXISTING FILE
V973           RMB     1                           * SECTOR NUMBER                        
V974           RMB     2                           * RAM DIRECTORY IMAGE ADDRESS                                      
V976           RMB     1                           * FIRST GRANULE NUMBER                               
*   UNUSED FILE
V977           RMB     1                           * SECTOR NUMBER                        
V978           RMB     2                           * RAM DIRECTORY IMAGE ADDRESS                                      

WFATVL         RMB     2                           * WRITE FAT VALUE: NUMBER OF FREE GRANULES WHICH MUST BE TAKEN                                                                         
* FROM THE FAT TO TRIGGER A WRITE FAT TO DISK SEQUENCE
DFFLEN         RMB     2                           * DIRECT ACCESS FILE RECORD LENGTH                                             
DR0TRK         RMB     4                           * CURRENT TRACK NUMBER, DRIVES 0,1,2,3                                                 
NMIFLG         RMB     1                           * NMI FLAG: 0=DON'T VECTOR <>0=YECTOR OUT                                                    
DNMIVC         RMB     2                           * NMI VECTOR: WHERE TO JUMP FOLLOWING AN NMI                                                       
*                                   INTERRUPT IF THE NMI FLAG IS SET
RDYTMR         RMB     1                           * MOTOR TURN OFF TIMER                                 
DRGRAM         RMB     1                           * RAM IMAGE OF DSKREG ($FF40)                                        
DVERFL         RMB     1                           * VERIFY FLAG: 0=OFF, $FF=ON                                       
ATTCTR         RMB     1                           * READ/WRITE ATTEMPT COUNTER: NUMBER OF TIMES THE                                                            
*                                   DISK WILL ATTEMPT TO RETRIEVE OR WRITE DATA
*                                   BEFORE IT GIVES UP AND ISSUES AN ERROR.

DFLBUF         RMB     SECLEN                      * INITIALIZED TO SECLEN BY DISKBAS                                                  

*RANDOM FILE RESERVED AREA

*FILE CONTROL BLOCKS AND BUFFERS

*GRAPHIC PAGE RESERVED AREA

*BASIC PROGRAM

*VARIABLE STORAGE AREA

*ARRAY STORAGE AREA


* FREE MEMORY


*STACK

*STRING SPACE

*USER PROGRAM RESERVED AREA

*END OF RAM

               ORG     $8000                                

               RMB     $2000                       * EXTENDED BASIC ROM                             
               RMB     $2000                       * COLOR BASIC ROM                          
*ROMPAK         EQU                                 *           
DOSBASSTART    RMB     $2000                       * DISK BASIC ROM/ENHANCED BASIC INIT CODE                                                        
               RMB     $1F00                       * ENHANCED BASIC                         

* START OF ADDITIONAL VARIABLES USED BY SUPER EXTENDED BASIC
H.CRSLOC       RMB     2                           * CURRENT LOCATION OF CURSOR                                         
H.CURSX        RMB     1                           * X POSITION OF CURSOR                                  
H.CURSY        RMB     1                           * Y POSITION OF CURSOR                                  
H.COLUMN       RMB     1                           * COLUMNS ON HI-RES ALPHA SCREEN                                             
H.ROW          RMB     1                           * ROWS ON HI-RES ALPHA SCREEN                                       
H.DISPEN       RMB     2                           * END OF HI-RES DISPLAY SCREEN                                           
H.CRSATT       RMB     1                           * CURRENT CURSOR'S ATTRIBUTES                                          
               RMB     1                           * UNUSED             
H.FCOLOR       RMB     1                           * FOREGROUND COLOR                               
H.BCOLOR       RMB     1                           * BACKGROUND COLOR                               
H.ONBRK        RMB     2                           * ON BRK GOTO LINE NUMBER                                     
H.ONERR        RMB     2                           * ON ERR GOTO LINE NUMBER                                     
H.ERROR        RMB     1                           * ERROR NUMBER ENCOUNTERED OR $FF (NO ERROR)                                                        
H.ONERRS       RMB     2                           * ON ERR SOURCE LINE NUMBER                                        
H.ERLINE       RMB     2                           * LINE NUMBER WHERE ERROR OCCURRED                                               
H.ONBRKS       RMB     2                           * ON BRK SOURCE LINE NUMBER                                        
H.ERRBRK       RMB     1                           * STILL UNKNOWN, HAS TO DO WITH ERR, BRK                                                     
H.PCOUNT       RMB     1                           * PRINT COUNT, CHARACTERS TO BE HPRINTED                                                     
H.PBUF         RMB     80                          * PRINT BUFFER, HPRINT CHARS. STORED HERE                                                     
               RMB     132                         * UNUSED               
INT.FLAG       RMB     1                           * INTERRUPT VALID FLAG. 0=NOT VALID, $55=VALID                                                           
* TABLE OF JUMP VECTORS TO INTERRUPT SERVICING ROUTINES
* INT.JUMP
INT.SWI3       RMB     3                                        
INT.SWI2       RMB     3                                        
INT.FIRQ       RMB     3                                        
INT.IRQ        RMB     3                                       
INT.SWI        RMB     3                                       
INT.NMI        RMB     3                                       

* I/O AREA
PIA0           EQU                                 $FF00              PERIPHERAL INTERFACE ADAPTER ONE                                                       

* BIT0 KEYBOARD ROW 1 AND RIGHT JOYSTICK SWITCH 1
* BIT1 KEYBOARD ROW 2 AND LEFT JOYSTICK SWITCH 1
* BIT2 KEYBOARD ROW 3 AND RIGHT JOYSTICK SWITCH 2
* BIT3 KEYBOARD ROW 4 AND LEFT JOYSTICK SWITCH 2
* BIT4 KEYBOARD ROW 5
* BIT5 KEYBOARD ROW 6
* BIT6 KEYBOARD ROW 7
* BIT7 JOTSTICK COMPARISON IINPUT

* BIT0 CONTROL OF HSYNC (63.5ps) 0 = IRQ * TO CPU DISABLED
* INTERRUPT 1 = IRQ * TO CPU ENABLED
* BIT1 CONTROL OF INTERRUPT 0 = FLAG SET ON FALLING EDGE OF HS
* POLARITY 1 = FLAG SET ON RISING EDGE OF HS
* BIT2 NORMALLY 1 0 = CHANGES FF00 TO DATA DIRECTION
* BIT3 SEL 1 LSB OF TWO ANALOG MUX SELECT LINES
* BIT4 ALWAYS 1
* BIT5 ALWAYS 1
* BIT6 NOT USED
* BIT7 HORIZONTAL SYNC INTERRUPT FLAG

* BIT0 KEYBOARD COLUMN 1
* BIT1 KEYBOARD COLUMN 2
* BIT2 KEYBOARD COLUMN 3
* BIT3 KEYBOARD COLUMN 4
* BIT4 KEYBOARD COLUMN 5
* BIT5 KEYBOARD COLUMN 6
* BIT6 KEYBOARD COLUMN 7 / RAM SIZE OUTPUT
* BIT7 KEYBOARD COLUMN 8

* BIT0 CONTROL OF VSYNC (16.667ms) 0 = IRQ * TO CPU DISABLED
* INTERRUPT 1 = IRQ * TO CPU ENABLED
* BIT1 CONTROL OF INTERRUPT 0 = FLAG SET ON FALLING EDGE OF FS
* POLARITY 1 = FLAG SET ON RISING EDGE OF FS
* BIT2 NORMALLY 1 0 = CHANGES FF02 TO DATA DIRECTION
* BIT3 SEL 2 MSB OF TWO ANALOG MUX SELECT LINES
* BIT4 ALWAYS 1
* BIT5 ALWAYS 1
* BIT6 NOT USED
* BIT7 FIELD SYNC INTERRUPT FLAG

PIA1           EQU                                 $ff20               PERIPHERAL INTERFACE ADAPTER TWO                                                        

* BIT0 CASSETTE DATA INPUT
* BIT1 RS-232C DATA OUTPUT
* BIT2 6 BIT D/A LSB
* BIT3 6 BIT D/A
* BIT4 6 BIT D/A
* BIT5 6 BIT D/A
* BIT6 6 BIT D/A
* BIT7 6 BIT D/A MSB

* BIT0 CONTROL OF CD 0 = FIRQ * TO CPU DISABLED
* (RS-232C STATUS) 1 = FIRQ * TO CPU ENABLED
* BIT1 CONTROL OF INTERRUPT 0 = FLAG SET ON FALLING EDGE OF CD
* POLARITY 1 = FLAG SET ON RISING EDGE OF CD
* BIT2 NORMALLY 1 0 = CHANGES FF20 TO DATA DIRECTION
* BIT3 CASSETTE MOTOR CONTROL 0 = OFF 1 = ON
* BIT4 ALWAYS 1
* BIT5 ALWAYS 1
* BIT6 NOT USED
* BIT7 CD INTERRUPT FLAG

* BIT0 RS-232C DATA INPUT
* BIT1 SINGLE BIT SOUND OUTPUT
* BIT2 RAM SIZE INPUT
* BIT3 RGB MONITOR SENSING INPUT CSS
* BIT4 VDG CONTROL OUTPUT GM0 & UPPER/LOWER CASE *
* BIT5 VDG CONTROL OUTPUT GM1 & INVERT
* BIT6 VDG CONTROL OUTPUT GM2
* BIT7 VDG CONTROL OUTPUT A */G

* BIT0 CONTROL OF CARTRIDGE 0 = FIRQ * TO CPU DISABLED
* INTERRUPT 1 = FIRQ * TO CPU ENABLED
* BIT1 CONTROL OF INTERRUPT 0 = FLAG SET ON FALLING EDGE OF CART *
* POLARITY 1 = FLAG SET ON RISING EDGE OF CART *
* BIT2 NORMALLY 1 0 = CHANGES FF22 TO DATA DIRECTION
* BIT3 SOUND ENABLE
* BIT4 ALWAYS 1
* BIT5 ALWAYS 1
* BIT6 NOT USED
* BIT7 CARTRIDGE INTERRUPT FLAG

* PIA2
DSKREG         EQU	$FF40                           * DISK CONTROL REGISTER                                  

* BIT0 DRIVE SELECT 0
* BIT1 DRIVE SELECT 1
* BIT2 DRIVE SELECT 2
* BIT3 DRIVE MOTOR ENABLE 0 = MOTORS OFF 1 = MOTORS ON
* BIT4 WRITE PRECOMPENSATION 0 = NO PRECOMP 1 = PRECOMP
* BIT5 DENSITY FLAG 0 = SINGLE 1 = DOUBLE
* BIT6 DRIVE SELECT 3
* BIT7 HALT FLAG 0 = DISABLED 1 = ENABLED

* FLOPPY DISK CONTROLLER INTERNAL REGISTERS
FDCREG         EQU     $FF48                           * STATUS/COMMAND REGISTER                                    

* COMMANDS	TYPE 	COMMAND 	CODE
* 		I 	RESTORE 	$03
* 		I 	SEEK 		$17
* 		I 	STEP 		$23
* 		I 	STEP IN 	$43
* 		I 	STEP OUT 	$53
* 		II 	READ SECTOR 	$80
* 		II 	WRITE SECTOR 	$A0
* 		III 	READ ADDRESS 	$C0
* 		III 	READ TRACK 	$E4
* 		III 	WRITE TRACK 	$F4
* 		IV 	FORCE INTERRUPT $D0

* STATUS BIT 	TYPE I 		READ ADDRESS/SECTOR/TRACK WRITE SECTOR/TRACK
* S0 		BUSY 		BUSY 				BUSY
* S1 		INDEX 		DRQ 				DRQ
* S2 		TRACK 0 	LOST DATA 			LOST DATA
* S3 		CRC ERROR 	CRC ERROR (EXCEPT TRACK) 	CRC ERROR (EXCEPT TRACK)
* S4 		SEEK ERROR 	RNF (EXCEPT TRACK) 		RNF (EXCEPT TRACK)
* S5 		HEAD LOADED 	RECORD TYPE (SECTOR ONLY) 	WRITE FAULT
* S6 		WRITE PROTECT 	WRITE PROTECT
* S7 		NOT READY 	NOT READY 			NOT READY

FDCTRACK       EQU     $FF49                       * TRACK REGISTER                     
FDCSECT        EQU     $FF4A                       * SECTOR REGISTER                      
FDCDATA        EQU     $FF4B                       * DATA REGISTER                    

	org	$ff50
	
               RMB     16                          * UNUSED SPACE                    
               RMB     1                           * X COORDINATE FOR X-PAD                             
               RMB     1                           * Y COORDINATE FOR X-PAD                             
               RMB     1                           * STATUS REGISTER FOR X-PAD                                
               RMB     5                           * UNUSED             
* RS-232 PROGRAM PAK
               RMB     1                           * READ/WRITE DATA REGISTER                               
               RMB     1                           * STATUS REGISTER                      
               RMB     1                           * COMMAND REGISTER                       
               RMB     1                           * CONTROL REGISTER                       
               RMB     4                                
               RMB     13                                
               RMB     1                           * SOUND/SPEECH CARTRIDGE RESET                                   
               RMB     1                           * SOUND/SPEECH CARTRIDGE READ/WRITE                                        
               RMB     1                           * MULTI-PAK PROGRAMMING REGISTER                                     

               RMB     64                          * RESERVED FOR FUTURE EXPANSION                                     

* VIDEO CONTROL REGISTERS
INIT0          RMB     1                           * INITIALIZATION REGISTER 0                                     

* BIT0 MC0 ROM MAP CONTROL (SEE TABLE BELOW)
* BIT1 MC1 ROM MAP CONTROL (SEE TABLE BELOW)
* BIT2 MC2 STANDARD SCS
* BIT3 MC3 1 = DRAM AT 0xFEXX IS CONSTANT
* BIT4 FEN 1 = CHIP FIRQ OUTPUT ENABLED
* BIT5 IEN 1 = CHIP IRQ OUTPUT ENABLED
* BIT6 M/P 1 = MMU ENABLED
* BIT7 COCO 1 = COCO 1 & 2 COMPATIBLE

* MC1 MC0 ROM MAPPING
* x 16K INTERNAL, 16K EXTERNAL
* 32K INTERNAL
* 32L EXTERNAL (EXCEPT FOR VECTORS)

INIT1          RMB     1                           * INITIALIZATION REGISTER 1                                     

* BIT0 TR MMU TASK REGISTER SELECT
* BIT1
* BIT2
* BIT3
* BIT4
* BIT5 TINS TIMER INPUT SELECT: 1=70ns, 0=63ns
* BIT6
* BIT7


IRQENR         RMB     1                           * IRQ INTERRUPT ENABLE REGISTER                                          

* BIT0 EI0 CARTRIDGE IRQ ENABLED
* BIT1 EI1 KEYBOARD IRQ ENABLED
* BIT2 EI2 SERIAL DATA IRQ ENABLED
* BIT3 VBORD VERTICAL BORDER IRQ ENABLED
* BIT4 HBORD HORIZONTAL BORDER IRQ ENABLED
* BIT5 TMR INTERRUPT FROM TIMER ENABLED
* BIT6
* BIT7

FIRQENR        RMB     1                           * FIRQ INTERRUPT ENABLE REGISTER                                            

* BIT0 EI0 CARTRIDGE FIRQ ENABLED
* BIT1 EI1 KEYBOARD FIRQ ENABLED
* BIT2 EI2 SERIAL DATA FIRQ ENABLED
* BIT3 VBORD VERTICAL BORDER FIRQ ENABLED
* BIT4 HBORD HORIZONTAL BORDER FIRQ ENABLED
* BIT5 TMR INTERRUPT FROM TIMER ENABLED
* BIT6
* BIT7

V.TIMER        RMB     2                           * TIMER REGISTER                            
               RMB     2                           * RESERVED FOR FUTURE EXPANSION                                    

VIDEOREG       RMB     1                           * VIDEO MODE REGISTER                                  

* BIT0 LPR0 LINES PER ROW (SEE TABLE BELOW)
* BIT1 LPR1 LINES PER ROW (SEE TABLE BELOW)
* BIT2 LPR2 LINES PER ROW (SEE TABLE BELOW)
* BIT3 H50 1 = 50 Hz VERTICAL REFRESH
* BIT4 MOCH 1 = MONOCHROME (ON COMPOSITE)
* BIT5 BPI 1 = BURST PHASE INVERTED
* BIT6
* BIT7 BP 0 = ALPHA, 1 = BIT PLANE

* LPR2 LPR1 LPR0 LINES PER CHARACTER ROW
* (GRAPHICS MODES)
* (COCO 1 & 2 ONLY)
* (COCO 1 & 2 ONLY)


* (RESERVED)

* (RESERVED)

*VIDEOREG       RMB     1                           * VIDEO MODE REGISTER                                  

* BIT0 CRES0 COLOR RESOLUTION
* BIT1 CRES1 COLOR RESOLUTION
* BIT2 HRES0 HORIZONTAL RESOLUTION
* BIT3 HRES1 HORIZONTAL RESOLUTION
* BIT4 HRES2 HORIZONTAL RESOLUTION
* BIT5 LPF0 LINES PER FIELD (SEE TABLE BELOW)
* BIT6 LPF1 LINES PER FIELD (SEE TABLE BELOW)
* BIT7

* LPF1 LPF0 LINES PER FIELD


* RESERVED


* VIDEO RESOLUTION
* ALPHA: BP = 0, COCO = 0
* MODE HRES2 HRES1 HRES0 CRES1 CRES0
* CHARACTER 0 0 1
* CHARACTER 0 1 1
* CHARACTER 1 1 1
* GRAPHICS: BP = 1, COCO = 0
* PIXELSxCOLORS HRES2 HRES1 HRES0 CRES1 CRES0
* 640x4 1 1 1 0 1
* 640x2 1 0 1 0 0
* 512x4 1 1 0 0 1
* 512x2 1 0 0 0 0
* 320x16 1 1 1 1 0
* 320x4 1 0 1 0 1
* 256x16 1 1 0 1 0
* 256x4 1 0 0 0 1
* 256x2 0 1 0 0 0
* 160x16 1 0 1 1 0

* COCO MODE SELECTION
* DISPLAY MODE REG. FF22
* V2 V1 V0 7 6 5 4 3
* ALPHA 0 0 0 0 x x 0 CSS
* ALPHA INVERTED 0 0 0 0 x x 0 CSS
* SEMIGRAPHICS 4 0 0 0 0 x x 0 x
* 64x64 COLOR GRAPHICS 0 0 1 1 0 0 0 CSS
* 128x64 GRAPHICS 0 0 1 1 0 0 1 CSS
* 128x64 COLOR GRAPHICS 0 1 0 1 0 1 0 CSS
* 128x96 GRAPHICS 0 1 1 1 0 1 1 CSS
* 128x96 COLOR GRAPHICS 1 0 0 1 1 0 0 CSS
* 128x96 GRAPHICS 1 0 1 1 1 0 1 CSS
* 128x96 COLOR GRAPHICS 1 1 0 1 1 1 0 CSS
* 256x192 GRAPHICS 1 1 0 1 1 1 1 CSS

* ALPHANUMERIC MODES
* TEXT SCREEN MEMORY
* EVEN BYTE
* BIT0 CHARACTER BIT 0
* BIT1 CHARACTER BIT 1
* BIT2 CHARACTER BIT 2
* BIT3 CHARACTER BIT 3
* BIT4 CHARACTER BIT 4
* BIT5 CHARACTER BIT 5
* BIT6 CHARACTER BIT 6
* BIT7

* ODD BYTE
* BIT0 BGND0 BACKGROUND COLOR BIT (PALETTE ADDR)
* BIT1 BGND1 BACKGROUND COLOR BIT (PALETTE ADDR)
* BIT2 BGND2 BACKGROUND COLOR BIT (PALETTE ADDR)
* BIT3 FGBD0 FOREGROUND COLOR BIT (PALETTE ADDR)
* BIT4 FGND1 FOREGROUND COLOR BIT (PALETTE ADDR)
* BIT5 FGND2 FOREGROUND COLOR BIT (PALETTE ADDR)
* BIT6 UNDLN CHARACTERS ARE UNDERLINED
* BIT7 BLINK CHARACTERS BLINK AT 1/2 SEC. RATE
* ATTRIBUTES NOT AVAILABLE WHEN COCO = 1
* GRAPHICS MODES
* COLOR MODES: (CRES1=1, CRES0 = 0)
* BYTE FROM DRAM
* BIT0 PA0, SECOND PIXEL
* BIT1 PA1, SECOND PIXEL
* BIT2 PA2, SECOND PIXEL
* BIT3 PA3, SECOND PIXEL
* BIT4 PA0, FIRST PIXEL
* BIT5 PA1, FIRST PIXEL
* BIT6 PA2, FIRST PIXEL
* BIT7 PA3, FIRST PIXEL
* COLOR MODES: (CRES1=0, CRES0 = 1)
* BYTE FROM DRAM
* BIT0 PA0, FOURTH PIXEL
* BIT1 PA1, FOURTH PIXEL
* BIT2 PA0, THIRD PIXEL
* BIT3 PA1, THIRD PIXEL
* BIT4 PA0, SECOND PIXEL
* BIT5 PA1, SECOND PIXEL
* BIT6 PA0, FIRST PIXEL
* BIT7 PA1, FIRST PIXEL
* COLOR MODES: (CRES1=0, CRES0 = 0)
* BYTE FROM DRAM
* BIT0 PA0, EIGHTH PIXEL
* BIT1 PA0, SEVENTH PIXEL
* BIT2 PA0, SIXTH PIXEL
* BIT3 PA0, FIFTH PIXEL
* BIT4 PA0, FORTH PIXEL
* BIT5 PA0, THIRD PIXEL
* BIT6 PA0, SECOND PIXEL
* BIT7 PA0, FIRST PIXEL
* PALETTE ADDRESSES
* ADDRESS PA3 PA2 PA1 PA0

















V.BORDER       RMB     1                           * BORDER REGISTER                              

* BIT0 BLU0 BLUE LSB
* BIT1 GRN0 GREEN LSB
* BIT2 RED0 RED LSB
* BIT3 BLU1 BLUE MSB
* BIT4 GRN1 GREEN MSB
* BIT5 RED1 RED MSB
* BIT6
* BIT7

               RMB     1                           * RESERVED               
V.SCROLL       RMB     1                           * VERTICAL SCROLL REGISTER                                       

* BIT0 VSC0
* BIT1 VSC1
* BIT2 VSC2
* BIT3 VSC3
* BIT4
* BIT5
* BIT6
* BIT7
* IN COCO MODE, THE VSC'S MUST BE INITIALIZED TO $0F

V.OFSET1       RMB     1                           * VERTICAL OFFSET 1 REGISTER                                         

* BIT0 Y11
* BIT1 Y12
* BIT2 Y13
* BIT3 Y14
* BIT4 Y15
* BIT5 Y16
* BIT6 Y17
* BIT7 Y18

V.OFSET0       RMB     1                           * VERTICAL OFFSET 0 REGISTER                                         

* BIT0 Y3
* BIT1 Y4
* BIT2 Y5
* BIT3 Y6
* BIT4 Y7
* BIT5 Y8
* BIT6 Y9
* BIT7 Y10
* IN COCO MODE, Y9-Y15 ARE NOT EFFECTIVE, AND ARE CONTROLLED BY
* SAM BITS F0-F6. ALSO IN COCO MODE, Y16-Y18 SHOULD BE 1, ALL OTHERS 0

H.OFSET0       RMB     1                           * HORIZONTAL OFFSET 0 REGISTER                                           

* BIT0 X0 HORIZONTAL OFFSET ADDRESS
* BIT1 X1 HORIZONTAL OFFSET ADDRESS
* BIT2 X2 HORIZONTAL OFFSET ADDRESS
* BIT3 X3 HORIZONTAL OFFSET ADDRESS
* BIT4 X4 HORIZONTAL OFFSET ADDRESS
* BIT5 X5 HORIZONTAL OFFSET ADDRESS
* BIT6 X6 HORIZONTAL OFFSET ADDRESS
* BIT7 XVEN HORIZONTAL VIRTUAL ENABLE
* HVEN ENABLES A HORIZONTAL SCREEN WIDTH OF 128 BYTES REGARDLESS OF THE
* HRES BITS AND CRES BITS SELECTED. THIS WILL ALLOW A 'VIRTUAL' SCREEN
* SOMEWHAT LARGER THAN THE DISPLAYED SCREEN. THE USER CAN MOVE THIS
* 'WINDOW' (THE DISPLAYED SCREEN) BY MEANS OF THE HORIZONTAL OFFSET
* BITS. IN CHARACTER MODE, THE SCREEN WIDTH IS 128 CHARACTERS REGARDLESS
* OF ATTRIBUTE (OR 64, IF DOUBLE-WIDE IS SELECTED).

MMUREG         RMB     16                          * MEMORY MANAGEMENT UNIT REGISTERS (6 BITS)                                                       

* RELATIONSHIP BETWEEN DATA IN TASK REGISTER AND GENERATED ADDRESS
* BIT D5 D4 D3 D2 D1 D0
* CORRESPONDING
* MEMORY ADDRESS A18 A17 A16 A15 A14 A13

* DATA FROM THE MMU IS THEN USED AS THE UPPER 6 ADDRESS LINES (A13-A18)
* FOR MEMORY ACCESS
* ADDRESS RANGE TR A15 A14 A13 MMU LOCATION
* X0000 - X1FFF 0 0 0 0 FFA0
* X2000 - X3FFF 0 0 0 1 FFA1
* X4000 - X5FFF 0 0 1 0 FFA2
* X6000 - X7FFF 0 0 1 1 FFA3
* X8000 - X9FFF 0 1 0 0 FFA4
* XA000 - XBFFF 0 1 0 1 FFA5
* XC000 - XDFFF 0 1 1 0 FFA6
* XE000 - XFFFF 0 1 1 1 FFA7

* X0000 - X1FFF 1 0 0 0 FFA8
* X2000 - X3FFF 1 0 0 1 FFA9
* X4000 - X5FFF 1 0 1 0 FFAA
* X6000 - X7FFF 1 0 1 1 FFAB
* X8000 - X9FFF 1 1 0 0 FFAC
* XA000 - XBFFF 1 1 0 1 FFAD
* XC000 - XDFFF 1 1 1 0 FFAE
* XE000 - XFFFF 1 1 1 1 FFAF

PALETREG       RMB     16                          * COLOR PALETTE REGISTERS (6 BITS)                                                

* DATA BIT D5 D4 D3 D2 D1 D0
* RGB OUTPUT R1 G1 B1 R0 G0 B0
* COMP. OUTPUT I1 I0 P3 P2 P1 P0

* FOR COCO COMPATIBILITY, THE FOLLOWING SHOULD BE LOADED ON INITIALIZATION
* (RGB VALUES) FOR PAL VERSION, IGNORE TABLE FOR COMPOSITE
* GREEN $12
* YELLOW $36
* BLUE $09
* RED $24
* BUFF $3F
* CYAN $10
* MAGENTA $2D
* ORANGE $26
* BLACK $00
* GREEN $12
* BLACK $00
* BUFF $3F
* BLACK $00
* GREEN $12
* BLACK $00
* ORANGE $26

SAMREG         EQU                                 *                SAM CONTROL REGISTERS                                                

V0CLR          RMB     1                           * CLEAR COCO GRAPHICS MODE V0                                       
V0SET          RMB     1                           * SET COCO GRAPHICS MODE V0                                     
V1CLR          RMB     1                           * CLEAR COCO GRAPHICS MODE V1                                       
V1SET          RMB     1                           * SET COCO GRAPHICS MODE V1                                     
V2CLR          RMB     1                           * CLEAR COCO GRAPHICS MODE V2                                       
V2SET          RMB     1                           * SET COCO GRAPHICS MODE V2                                     
F0CLR          RMB     1                           * CLEAR COCO GRAPHICS OFFSET F0                                         
F0SET          RMB     1                           * SET COCO GRAPHICS OFFSET F0                                       
F1CLR          RMB     1                           * CLEAR COCO GRAPHICS OFFSET F1                                         
F1SET          RMB     1                           * SET COCO GRAPHICS OFFSET F1                                       
F2CLR          RMB     1                           * CLEAR COCO GRAPHICS OFFSET F2                                         
F2SET          RMB     1                           * SET COCO GRAPHICS OFFSET F2                                       
F3CLR          RMB     1                           * CLEAR COCO GRAPHICS OFFSET F3                                         
F3SET          RMB     1                           * SET COCO GRAPHICS OFFSET F3                                       
F4CLR          RMB     1                           * CLEAR COCO GRAPHICS OFFSET F4                                         
F4SET          RMB     1                           * SET COCO GRAPHICS OFFSET F4                                       
F5CLR          RMB     1                           * CLEAR COCO GRAPHICS OFFSET F5                                         
F5SET          RMB     1                           * SET COCO GRAPHICS OFFSET F5                                       
F6CLR          RMB     1                           * CLEAR COCO GRAPHICS OFFSET F6                                         
F6SET          RMB     1                           * SET COCO GRAPHICS OFFSET F6                                       
               RMB     4                           * RESERVED               
R1CLR          RMB     1                           * CLEAR CPU RATE, (0.89 MHz)                                      
R1SET          RMB     1                           * SET CPU RATE, (1.78 MHz)                                    
               RMB     4                           * RESERVED               
ROMCLR         RMB     1                           * ROM DISABLED                         
ROMSET         RMB     1                           * ROM ENABLED                        

               RMB     18                          * RESERVED FOR FUTURE MPU ENHANCEMENTS                                            
*         INTERRUPT VECTORS
SWI3HWV        RMB     2            
SWI2HWV        RMB     2            
FIRQ           RMB     2                                    
IRQ            RMB     2                                   
SWIHWV         RMB     2           
NMI            RMB     2                                   
RESETV         RMB     2                                      

DLODFL    	EQU	$095D			* Do load flag
L813C      	EQU	$813C
L8168      	EQU	$8168			* IF NOT POS, GO TO EXBAS SEC
L8311      	EQU	$8311			* JUMP TO EXBAS' CLOAD
L8316      	EQU	$8316			* GO CHECK FOR CSAVEM
L836C      	EQU	$836C			* EVALUATE EXPRESSION, PUT II
L8748           EQU	$8748	            	* EVALUATE A STRING EXPRESSION
L880E      	EQU	$880E			*CONVERT TO FLOATING POINT NU
L8955           EQU	$8955            	* JUMP TO EXTENDED BASIC'S IRQ HANDLER
L8C1B      	EQU	$8C1B			* JUMP TO EXEAS' DLOAD 
L95AC      	EQU	$95AC			* RESET SAM DISPLAY PAGE AND
L9650      	EQU	$9650			* BRANCH IF COMMA
L962E      	EQU	$962E			* JUMP TO EXEAS' PMODE COMMAN
L96CB      	EQU	$96CB			* READJUST LINE NUMBERS, ETC
L96EC		EQU	$96EC			* Init Exbas vars
L975F     	EQU	$975F			* COMING FROM EXBAS' GET/PUT?
L9FB5      	EQU	$9FB5			* MULT (UNSIGNED)
LA0E2		EQU	$A0E2			* Jump back to basic
BAWMST      	EQU	$A0E8
LA171      	EQU	$A171			* GET A CHARACTER FROM CONSOL
LA176      	EQU	$A176			* GET A CHAR FROM INPUT BUFFE
LA282		EQU	$A282                   * SEND CHARACTER TO CONSOLE OUT
LA35F      	EQU	$A35F			* SET PRINT PARAMETERS 
LA37C      	EQU	$A37C			* SAVE THE PRINT PARAMETERS
LA3ED      	EQU	$A3ED			* VERIFY THAT THE FILE TYPE
LA3FB      	EQU	$A3FB			* 'FILE NOT OPEN' ERROR
LA406      	EQU	$A406			* TEST DEVICE NUMBER 
LA426      	EQU	$A426			* CLOSE ALL FILES 
LA429      	EQU	$A429			* CLOSE FILES 
LA42D      	EQU	$A42D			* CLOSE FILE 
LA549      	EQU	$A549			* GO DO A BREAK CHECK
LA59A		EQU	$A59A			* move B bytes from X to U
LA5A2      	EQU	$A5A2			* GET DEVICE NUMBER
LA5A5           EQU	$A5A5			* EVALUATE AN EXPRESSION (DEVICE NUMBER)
LA5AE           EQU	$A5AE            	* STRIP DEVICE NUMBER OFF OF INPUT LINE
LA5C7      	EQU	$A5c7			* ERROR IF ANY FURTHER CHARAC
LA5DA           EQU	$A5DA            	* BRANCH BACK TO  BASIC'S EOF IF NOT DISK FILE
LA5E4           EQU	$A5E4            	* LINK BACK TO BASIC'S EOF STATEMENT
LA603		EQU	$A603
LA616      	EQU	$A616			* 'BAD FILE MODE' ERROR
LA61C      	EQU	$A61C			* 'FILE ALREADY OPEN' ERROR
LA61F      	EQU	$A61F			* 'DEVICE NUMBER' ERROR
LA7E9      	EQU	$A7E9			* TURN OFF THE CASSETTE MOTOR
LA7D1      	EQU	$A7D1			* WAIT A WHILE 
LA928      	EQU	$A928			* CLEAR SCREEN 
LA951      	EQU	$A951			* JUMP TO 'SOUND' - DO A BEEP
LA974      	EQU	$A974			* DISABLE THE ANALOG MUX
LAC37      	EQU	$AC37			* SEE OF ENOUGH ROOM IN RAM
LAC44      	EQU	$AC44			* 'OUT OF MEMORY' ERROR 
LAC46      	EQU	$AC46			* JUMP TO ERROR HANDLER
LAC60      	EQU	$AC60			* JUMP TO BASIC'S ERROR HANDL
LAC73      	EQU	$AC73			* RETURN TO DIRECT MODE    
LAC7C      	EQU	$AC7C			* GO TO BASIC'S MAIN LOOP,
LACEF      	EQU	$ACEF			* RELOCATE ALL THE BASIC NEX
LAD19		EQU	$AD19      		* DO A 'NEW' - RESET POINTERS
LAD21      	EQU	$AD21			* DO PART OF NEW - ERASE VARI
LAD33      	EQU	$AD33			* RESET THE CONT FLAG, ETC
LAD9E      	EQU	$AD9E			* BRANCH TO COMM INTERPRETATI
LADC6		EQU	$ADC6                   * LOOP THROUGH BASIC'S MAIN INTERPRETATION LOOP
LADEB           EQU	$ADEB            	* GO DO A BREAK CHECK IF A KEY IS DOWN
LADD4		EQU	$ADD4			* Basic command handler
LAE15      	EQU	$AE15			* GO 'STOP' THE SYSTEM
LAF9A		EQU	$AF9A
LAFA4      	EQU	$AFA4			* BRANCH BACK TO BASIC'S 'LET
LAFB1      	EQU	$AFB1			* BRANCH IF STRING STORED 
LB00C		EQU	$B00C			* RETURN UNLESS COMING FROM basic 'input' statement
LB01E     	EQU	$B01E			* GET MODIFIED REENTRY POINT
LB069     	EQU	$B069
LB143      	EQU	$B143			* 'TM' ERROR IF VALTYP=STRING
LB146      	EQU	$B146			* 'TM' ERROR IF NUMERIC VARIA
LB148      	EQU	$B148			* DO A 'TM' CHECK
LB156      	EQU	$B156			* EVALUATE AN EXPRESSION
LB166     	EQU	$B166			* COMING FROM THE 'LET' COMMA
LB244           EQU	$B244            	* STRIP PROMPT STRING FROM BASIC AND PUT IT ON THE STRING STACK
LB262		EQU	$B262			* Basic check for (
SYNCOMMA 	EQU	$B26D			* Check for comma
LB26F           EQU	$B26F            	* DO A SYNTAX CHECK FOR char in B
LB277		EQU	$B277			* Basic ?SN error address
LB2CE		EQU	$B2CE			* jump to basic's secondary ?
LB357      	EQU	$B357			* EVALUATE VARIABLE
LB3E6      	EQU	$B3E6			* EVALUATE EXPRESSION
LB44A		EQU	$B44A			* Basic ?FC error address
LB4F3      	EQU	$B4F3			* LOAD ACCB INTO FPA0
GIVABF        	EQU	$B4F4
LB50F      	EQU	$B50F			* RESERVE FIVE BYTES IN STRIN
LB516      	EQU	$B516			* PUT ON TEMPORARY STRING STA
LB659      	EQU	$B659			* GET THE LENGTH AND ADDRESS
LB6A4      	EQU	$B6A4			* GET MODE(I,O,R) - FIRST BYTE
LB654      	EQU	$B654			* GET LENGTH AND ADDRESS OF S
LB657           EQU	$B657            	* PURGE THE STRING PUT ON THE STRING STACK
LB69B      	EQU	$B69B			* SAVE STRING DESCRIPTOR ON 
EVALEXPB 	EQU	$B70B			* EVALUATE EXPR; RETURN VALUE
LB70E      	EQU	$B70E			*EVALUATE NUMERIC EXPRESSION 
LB738      	EQU	$B738			* SYNTAX CHECK FOR COMMA,
LB73D      	EQU	$B73D			* EVALUATE EXPRESSION -
LIST		EQU	$B764			* Basic list
LB958      	EQU	$B958			* PRINT CARRIAGE RETURN TO CO
LB95C      	EQU	$B95C			* SEND A CR TO THE SCREEN 
STRINOUT 	EQU	$B99C  
LB99F      	EQU	$B99F			* PRINT STRING TO CONSOLE OUT
LB9A2      	EQU	$B9A2			* SEND FILENAME TO CONSOLE OU
LB9AC      	EQU	$B9AC			* SEND BLANK TO CONSOLE OUT 
LB9AF      	EQU	$B9AF			* SEND A '?' TO THE SCREEN
LB9C5      	EQU	$B9C5			* ADD NUMBER BYTES IN LAST SE
LBB91      	EQU	$BB91			* DIVIDE TOTAL NUMBER OF BYTE
LBC14      	EQU	$BC14			* COPY A PACKED FP NUMBER FRO
LBC33      	EQU	$BC33			* IF NUMERIC VARIABLE, PACK 
LBC35      	EQU	$BC35			* PACK FPA0 AND STORE IT IN S
LBC5F      	EQU	$BC5F			* SAVE NUMBER OF BYTES IN FUL
INT           	EQU	$BCEE			* CONVERT FPA0 TO AN INTEGER
LBDCC           EQU	$BDCC            	* CONVERT ACCD TO DECIMAL & PRINT IT ON SCREEN
LBDD9      	EQU	$BDD9			* CONVERT FP NUMBER TO ASCII 
XBWMST		EQU	$80C0			* Exbas warm reset
XVEC3        	EQU	$8273
XVEC4      	EQU	$8CF1
XVEC8        	EQU	$8286
XVEC9           EQU	$8E90
XVEC15       	EQU	$8846			* EXTENDED BASIC EXPRESSION E
XVEC17     	EQU	$88F0			* BRANCH TO EXBAS ERROR HANDL
XVEC18       	EQU	$829C			* JUMP TO EXBAS RUN 
AS		EQU	$B277






